<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post('/api/locTypeBind/init', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.add.success', '初始化成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const locQueryList = ref(null);
locQuery();
function locQuery() {
    postForm('/api/loc/query', {}).then(resp => {
        let result = resp.data;
        locQueryList.value = result.data;
    })
}
const locTypeQueryList = ref(null);
locTypeQuery();
function locTypeQuery() {
    post('/api/locType/tree', {}).then(resp => {
        let result = resp.data;
        locTypeQueryList.value = result.data;
    })
}
const userQueryList = ref(null);
userQuery();
function userQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        userQueryList.value = result.data;
    })
}


defineExpose({
    open,
})

</script>

<script>
export default {
    name: '库位类型绑定-init'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open" :title="formatMessage('page.init', '初始化')" @ok="handleOk" style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }"
                :wrapper-col="{ span: 16 }" style="display: flex;justify-content: space-between;flex-wrap: wrap;"
                autocomplete="off" @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item :label="formatMessage('db.man_loc_area_type.type_id', '库位类型')" name="typeId"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-tree-select v-model:value="formData.typeId" show-search style="width: 100%"
                        :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                        :placeholder="formatMessage('page.input', '请输入')" allow-clea tree-data-simple-mode
                        :tree-data="locTypeQueryList" tree-node-filter-prop="name" :field-names="{
                            children: 'children',
                            label: 'name',
                            value: 'id',
                        }">
                        <template #title="{ value: id, name }">
                            {{ name }}
                        </template>
                    </a-tree-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.start_row', '起始排')" name="startRow"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startRow" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.target_row', '结束排')" name="targetRow"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetRow" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.start_bay', '起始列')" name="startBay"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startBay" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.target_bay', '结束列')" name="targetBay"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetBay" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.start_lev', '起始层')" name="startLev"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startLev" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_loc_area_type.target_lev', '结束层')" name="targetLev"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetLev" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
